
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/BujarMurati/docster)

# docster
Docster is a static analysis tool that extracts doc strings from your code and inserts them into any Jinja2 template of your liking.
Use this tool to automatically build documentation for your project.
Because docster performs static analysis instead of importing your modules, it is safe to use on modules whose import could cause side effects.

